("GNU" "GNU")
("LaTeX" "LaTeX")
("TeX" "TeX")
("a modifier" "modificateur A")
("a series" "srie A")
("abbreviation" "abrviation")
("about" "sur")
("about menu" "sur")
("above" "en haut")
("abstract" "rsum")
("accent" "accent")
("accept" "accepter")
("accept all scripts" "accepter tous les scripts")
("accept no scripts" "ne jamais accepter de scripts")
("accept script" "accepter script")
("acknowledgment" "remerciements")
("acronym" "sigle")
("action" "action")
("activate" "activer")
("activate once" "activer une fois")
("activate hidden" "activer et cacher")
("activation" "activation")
("acute" "aigu")
("add package" "ajouter packetage")
("add switch after" "ajouter commutateur aprs")
("add switch before" "ajouter commutateur avant")
("address" "adresse")
("address block" "bloc d'adresse")
("advanced" "niveau suprieur")
("advanced layout features" "mise en page avance")
("after" "aprs")
("albanian" "albanais")
("algorithm" "algorithme")
("align cell to the bottom" "aligner la cellule en bas")
("align cell to the left" "aligner la cellule  gauche")
("align cell to the right" "aligner la cellule  droite")
("align cell to the top" "aligner la cellule en haut")
("align table at base of left column" "aligner tableau  la base de la colonne  gauche")
("align table at base of middle column" "aligner tableau  la base de la colonne au centre")
("align table at base of origin column" "aligner tableau  la base de la colonne d'origine")
("align table at base of right column" "aligner tableau  la base de la colonne  droite")
("align table at fraction bar height" "aligner tableau  la hauteur des barres des fractions")
("align table at the base of bottom row" "aligner tableau  la base de la ligne du bas")
("align table at the base of middle row" "aligner tableau  la base de la ligne du milieu")
("align table at the base of origin row" "aligner tableau  la base de la ligne d'origine")
("align table at the base of top row" "aligner tableau  la base de la ligne du haut")
("align table at the bottom" "aligner tableau en bas")
("align table at the center" "aligner tableau au centre")
("align table at the horizontal center" "aligner tableau au centre horizontal")
("align table at the left" "aligner tableau  gauche")
("align table at the top" "aligner tableau en haut")
("align table to the right" "aligner tableau  droite")
("align text to the left" "aligner le texte  gauche")
("align text to the right" "aligner le texte  droite")
("aligned" "align")
("alignment" "alignement")
("all" "le tout")
("allow" "permettre")
("allowed extension" "extension permise")
("allowed reduction" "rduction permise")
("alpha release" "version alpha")
("alt key" "touche alt")
("alternative specification" "spcification alternative")
("american" "amricain")
("and" "et")
("angular" "angulaire")
("appendix" "annexe")
("apply" "appliquer")
("apply macro" "appliquer macro")
("apply macro once" "appliquer macro une fois")
("april" "avril")
("arab" "arabe")
("arch series" "srie arch")
("archaic" "archaque")
("architecture" "architecture")
("argument" "argument")
("arithmetic" "arithmtique")
("armenian" "armnien")
("arrow" "flche")
("arrows" "flches")
("article" "article")
("as on paper" "comme sur le papier")
("assign" "changer")
("at fraction bar height" " l'hauteur des barres des fractions")
("at the baseline" " la ligne de base")
("at the bottom" "en bas")
("at the left" " gauche")
("at the middle" "au milieu")
("at the right" " droite")
("at the top" "en haut")
("attach" "attacher")
("attach buffer to which project" "attacher tampon  quel projet")
("august" "aot")
("author" "auteur")
("authorize" "authoriser")
("automatic" "automatique")
("automatically close brackets" "fermer automatiquement les parenthses")
("automatically generated content" "gnration automatique de contenu")
("automatic quotes" "guillemets automatiques")
("autosave" "sauvegarde automatique")
("axis" "axe")
("axiom" "axiome")
("b series" "srie B")
("background" "arrire-plan")
("background color" "couleur de fond")
("background evaluations" "valuations en arrire-plan")
("backward replace" "remplacement en arrire")
("backward search" "recherche en arrire")
("bad data format" "mauvais format de fichier")
("bar" "barre")
("bard" "bard")
("base level" "niveau infrieur")
("bashkirian" "bashkirien")
("basic" "base")
("basic communication using pipes" "communication de base par tubes")
("basic data types" "types de base")
("basic types" "types de base")
("be useful" "soyez utile")
("become a TeXmacs developer" "devenez un dveloppeur TeXmacs")
("before" "avant")
("begin" "dbut")
("below" "en bas")
("beta release" "version bta")
("bibliography" "bibliographie")
("bibliography file" "fichier de bibliographie")
("bibliography style" "style de bibliographie")
("big" "grand")
("big figure" "grande figure")
("big operator" "grand oprateur")
("big skip" "grand saut")
("big table" "grand tableau")
("binary operation" "opration binaire")
("binary relation" "relation binaire")
("black" "noir")
("blackboard bold" "tableau noir gras")
("blackboard math" "tableau noir math")
("blackletter" "lettre noir")
("blue" "bleu")
("body" "corps")
("bold" "gras")
("book" "livre")
("border" "bordure")
("both" "les deux")
("bottom" "en bas")
("bottom border" "bordure en bas")
("bottom cell border" "bordure en bas de la cellule")
("bottom cell padding" "espacement en bas de la cellule")
("bottom margin" "marge en bas")
("bottom padding" "espacement en bas")
("bottom table border" "bordure en bas du tableau")
("bottom table padding" "espacement en bas du tableau")
("branch" "branche")
("break" "saut")
("breaking" "sauts")
("breve" "demi-cercle")
("british" "britannique")
("broken white" "blanc cass")
("brown" "brun")
("browse" "naviguer")
("browse web" "naviguer sur le rseau")
("browser" "navigateur")
("buffer" "tampon")
("bulgarian" "bulgare")
("bullet" "puce")
("bullets" "puces")
("by" "par")
("by typing" "en tapant")
("bytes free" "octets de libre")
("bytes used" "octets utiliss")
("calligraphic" "calligraphique")
("cancel" "annuler")
("caps-lock key" "touche majuscules")
("case" "choisir")
("cc" "copies ")
("cell" "cellule")
("cell background color" "couleur de la cellule")
("cell border" "bordure de la cellule")
("cell height" "hauteur de la cellule")
("cell operation mode" "mode d'opration sur les cellules")
("cell width" "largeur de la cellule")
("center" "centr")
("center text" "centrer le texte")
("centered" "centr")
("centered block" "bloc centr")
("centered tabular" "tableau centr")
("change border of cell" "changer bordure de la cellule")
("change cell operation mode" "changer mode d'opration")
("change log" "tous les changements")
("changes" "changements")
("chapter" "chapitre")
("check" "tchche")
("check text for spelling errors" "vrifier le texte pour des fautes d'orthographe")
("chinese" "chinois")
("choice" "choix")
("citation" "citation")
("cite" "citer")
("class" "classe")
("clear" "effacer")
("clear selection" "effacer slection")
("clipped" "tronqu")
("clipped and magnified" "tronqu et agrandi")
("clipped and resized" "tronqu et redimensionn")
("clone" "cloner")
("clone window" "cloner fentre")
("close" "fermer")
("close TeXmacs" "fermer TeXmacs")
("close buffer" "fermer tampon")
("close session" "fermer la session")
("close window" "fermer fentre")
("closing" "fermeture")
("closing style" "style de fermeture")
("code" "code")
("color" "couleur")
("column" "colonne")
("column contains glued items" "la colonne contient des parties colles")
("common formats" "formats courants")
("compact" "compact")
("compactification" "compactification")
("compactify" "compactifier")
("compatibility with other formats" "compatibilit avec les autres formats")
("compile article" "compiler un article")
("compile book" "compiler un livre")
("compile buffer" "compiler tampon")
("compile project" "compiler projet")
("completion" "compltion")
("complex" "complexe")
("concrete" "concret")
("condensed" "condens")
("condition" "condition")
("configuration" "configuration")
("contact" "contact")
("content" "contenu")
("content tag" "balise")
("context dependent icons" "icnes dpendantes du contexte")
("continuation of" "continuation de")
("contribute" "contribuer")
("control the evaluation of expressions" "contrler l'valuation des expressions")
("convention" "convention")
("converters to other data formats" "convertisseurs pour d'autres formats")
("copy" "copier")
("copy text" "copier du texte")
("copy to" "copier vers")
("copying" "copier")
("corollary" "corollaire")
("correct text" "corrige texte")
("create web site" "cration d'un site web")
("cursors" "curseurs")
("custom tab" "tabulation personnalis")
("customizing TeXmacs" "personnalisation")
("customizing the TeXmacs styles" "personnaliser les styles TeXmacs")
("custum tab" "tabulation personnalise")
("cut" "couper")
("cut text" "couper du texte")
("cut to" "couper vers")
("cypriot" "cypriote")
("cyrillic" "cyrillique")
("cyrillic input method" "cyrillique par le clavier")
("cyrillic italic right" "cyrillique italique droit")
("czech" "tchque")
("dancers" "danseurs")
("danish" "danois")
("dark grey" "gris fonc")
("dash" "tiret")
("dashes" "tirets")
("data conversion" "conversion des donnes")
("data format" "format des donnes")
("date" "date")
("deactivate" "desactiver")
("deactivate table" "desactiver tableau")
("december" "dcembre")
("decorate atoms" "dcorations atomiques")
("default" "valeur par dfaut")
("default padding" "espacement par dfaut")
("definition" "dfinition")
("delete" "supprimer")
("delete column" "supprimer colonne")
("delete row" "supprimer ligne")
("denominator" "dnominateur")
("description" "description")
("destination" "destination")
("detach" "dtacher")
("detailed" "dtaill")
("determinant" "dterminant")
("devangari" "dvangari")
("developers guide" "guide du dveloppeur")
("directory" "rpertoire")
("disable" "dsactiver")
("disable first indentation" "dsactiver premire indentation")
("disable first indentation after" "dsactiver premire indentation aprs")
("disable first indentation before" "dsactiver premire indentation avant")
("disable indentation" "dsactiver indentation")
("disable indentation after" "dsactiver indentation aprs")
("disable indentation before" "dsactiver indentation avant")
("disable last indentation" "dsactiver dernire indentation")
("disable last indentation after" "dsactiver dernire indentation aprs")
("disable last indentation before" "dsactiver dernire indentation avant")
("disactivate" "disactiver")
("disactivate once" "disactiver une fois")
("disallow" "interdire")
("distribute unused space" "distribuer espace non utilis")
("div" "div")
("do not remap" "ne pas renvoyer")
("document" "document")
("document format" "format de document")
("document style" "style de document")
("document styles" "styles de document")
("documentation" "documentation")
("documents are trees" "les documents sont des arbres")
("dot" "rond")
("dots" "ronds")
("double stroke" "lignes doubles")
("down" "en bas")
("download" "tlcharger")
("dpi" "points par pouce")
("duplicate" "en double")
("dutch" "nerlandais")
("dynamic libraries" "librairies dynamiques")
("edit" "diter")
("edit source tree" "diter l'arbre source")
("editing tools" "outils d'dition")
("email" "email")
("emphasize" "mis en relief")
("emphasize text" "mettre en relief du texte")
("empty box" "bote vide")
("enable first indentation" "activer premire indentation")
("enable first indentation after" "activer premire indentation aprs")
("enable first indentation before" "activer premire indentation avant")
("enable indentation" "activer indentation")
("enable indentation after" "activer indentation aprs")
("enable indentation before" "activer indentation avant")
("enable last indentation" "activer dernire indentation")
("enable last indentation after" "activer dernire indentation aprs")
("enable last indentation before" "activer dernire indentation avant")
("encl" "inclus")
("end" "fin")
("english" "anglais")
("enter a title" "entrer un titre")
("enumerate" "numration")
("enumerate|Alpha" "Lettres")
("enumerate|Roman" "Romain")
("enumerate|alpha" "lettres")
("enumerate|roman" "romain")
("env" "environnement")
("environment" "environnement")
("epilogue" "pilogue")
("equal" "gal ")
("equation" "quation")
("equations" "quations")
("equivalent for" "quivalent pour")
("error" "erreur")
("esperanto" "espranto")
("etruscan" "trusque")
("evaluate" "valuer")
("evaluate scheme expression" "valuer expression scheme")
("even page footer" "en bas pour pages paires")
("even page header" "en-tte pour pages paires")
("even page margin" "marge pour pages paires")
("even page left margin" "marge  gauche pour pages paires")
("even page shift" "dcalage pour les pages paires")
("even page text" "texte pour les pages paires")
("exact horizontal" "horizontal exact")
("exact mode" "mode exact")
("exam" "examen")
("example" "exemple")
("exclusive" "exclusif")
("exclusive or" "ou exclusif")
("executable" "excutable")
("execute" "excuter")
("execute a TeXmacs command" "executer une commande TeXmacs")
("execute system command" "executer commande systme")
("executive" "excutif")
("exercise" "exercice")
("expand" "dvelopper")
("explained" "dtaill")
("export" "exporter")
("export as" "exporter en tant que")
("extend or normal" "'extend' ou 'normal'")
("extern " "externe")
("extra" "extra")
("extract format" "extraire format")
("extras" "extra")
("family" "famille")
("february" "fvrier")
("figure" "figure")
("file" "fichier")
("file name" "nom de fichier")
("file not found" "fichier non trouv")
("find next match" "chercher l'occurrence suivante")
("find text" "chercher du texte")
("finnish" "finlandais")
("first contact" "premier contact")
("first indentation" "premire indentation")
("first item" "premier lment")
("first page" "premire page")
("first start" "dmarrage")
("flat" "plat")
("flexibility" "flexibilit")
("flexibility factor for vertical spacing" "facteur de flexibilit pour l'espacement vertical")
("floating figure" "figure flottante")
("floating object" "objet flottant")
("floating table" "tableau flottant")
("fold" "plier")
("fold input field" "plier champ d'entre")
("folded" "pli")
("font" "police")
("font base size" "taille de police de base")
("font dpi" "points par pouce")
("font family" "famille de police")
("font name" "nom de police")
("font series" "espce de police")
("font shape" "forme de police")
("font size" "taille de police")
("font type" "type de police")
("font variant" "variante de police")
("fonts" "polices")
("footer" "en bas")
("footnote" "note en bas de page")
("for" "pour")
("foreground" "premier-plan")
("foreign" "tranger")
("format" "format")
("formatted and structured output" "sorties formattes et structures")
("formatted date" "date formate")
("formatting" "formattage")
("formula" "formule")
("formula style" "style formules")
("forward replace" "remplacement en avant")
("forward search" "recherche en avant")
("fraction" "fraction")
("french" "franais")
("full manuals" "manuels complets")
("function" "fonction")
("functional" "fonctionnel")
("further customization" "personnalisation")
("future changes" "changements  venir")
("gNU TeXmacs comes without any form of legal warranty" "GNU TeXmacs n'offre aucune garantie juridique")
("gNU TeXmacs falls under the GNU general public license" "GNU TeXmacs tombe sous la ``GNU general public license''")
("general architecture of TeXmacs" "architecture gnrale de TeXmacs")
("general negation" "ngation gnrale")
("general note" "note gnrale")
("generating font file" "Gnration du fichier de police")
("generic" "gnrique")
("georgian" "gorgien")
("german" "allemand")
("getting started" "commencer")
("glossary" "glossaire")
("glossary entry" "entre dans le glossaire")
("glue" "coller")
("glue decorations" "coller dcorations")
("go" "aller")
("gothic" "gothique")
("graphical interface" "interface graphique")
("grave" "grave")
("greater" "suprieur ")
("greater or equal" "suprieur ou gal ")
("greek" "grecque")
("greek letter" "lettre grecque")
("green" "vert")
("grey" "gris")
("group" "groupe")
("h modifier" "modificateur H")
("happy typing" "bonne rdaction")
("has been aborted" "a t arrte")
("has completed its task" "a effectu sa tche")
("hat" "circonflexe")
("header" "en-tte")
("header and footer" "en-tte et bas de page")
("hebrew" "hbreu")
("height" "hauteur")
("height is exactly the specified height" "utiliser la hauteur spcifie")
("height is maximum of specified height and box height" "utiliser maximum de la hauteur spcifie et la hauteur de la bote")
("height is minimum of specified height and box height" "utiliser minimum de la hauteur spcifie et la hauteur de la bote")
("height magnification" "agrandissement de la hauteur")
("help" "aide")
("help me" "aidez-moi")
("help us" "aidez-nous")
("here" "ici")
("hidden" "cach")
("home" "racine")
("homepage" "page d'acceuil")
("horizontal" "horizontal")
("horizontal cell alignment" "alignement horizontal de la cellule")
("horizontal ink separation" "sparation d'encre horizontale")
("horizontal part" "partie horizontale")
("horizontal position" "position horizontale")
("horizontal space" "espace horizontal")
("horizontal table alignment" "alignement horizontal du tableau")
("horizontally align cell to the base" "alignement horizontale de la cellule sur la base")
("horizontally center the cell" "centrer la cellule horizontalement")
("how much longer may pages become" "par combien les pages peuvent-elles se rallonger")
("how much shorter may pages become" "par combien les pages peuvent-elles se raccourcir")
("huge" "norme")
("hungarian" "hongrois")
("hybrid command" "commande hybride")
("hyperlink" "hyperlien")
("hyphenation" "csure")
("icelandic" "islandais")
("if" "si")
("image" "image")
("image links" "images lis")
("implementation" "implantation")
("import" "importer")
("improving the current implementation" "amlioration de l'implantation prsente")
("inactive" "inactif")
("include" "inclure")
("include a document" "inclure un document")
("include file" "inclure un fichier")
("inclusion into TeXmacs" "inclusion dans TeXmacs")
("inclusions" "inclusions")
("indent" "indenter")
("indentation flag" "indentation")
("index" "index")
("index entry" "entre dans l'index")
("index level" "niveau d'indices")
("informative flags" "drapeaux informatifs")
("inline arguments" "arguments en ligne")
("input mode" "mode des entres")
("insert" "insrer")
("insert Pr" "insrer Pr")
("insert a TeXmacs symbol" "insrer un symbole TeXmacs")
("insert a big operator" "insrer un grand oprateur")
("insert a binary operation" "insrer une opration binaire")
("insert a binary relation" "insrer une relation binaire")
("insert a blackboard bold character" "insrer un caractre gras de tableau noir")
("insert a bold calligraphic character" "insrer un caractre calligraphique gras")
("insert a bold character" "insrer un caractre gras")
("insert a calligraphic character" "insrer un caractre calligraphique")
("insert a condition" "insrer une condition")
("insert a control flow instruction" "insrer une instruction de flux de contrle")
("insert a fraction" "insrer une fraction")
("insert a fraktur character" "insrer un caractre Gothique")
("insert a greek character" "insrer un caractre grec")
("insert a large left delimiter" "insrer un grand dlimiteur  gauche")
("insert a large right delimiter" "insrer un grand dlimiteur  droite")
("insert a large separator" "insrer un grand sparateur")
("insert a left subscript" "insrer un indice  gauche")
("insert a link" "insrer un lien")
("insert a miscellaneous symbol" "insrer un symbole divers")
("insert a new branch" "insre une nouvelle branche")
("insert a new item" "insrer un nouvel lment")
("insert a numerical operation" "insrer une opration numrique")
("insert a picture" "insrer une image")
("insert a square root" "insrer une racine carre")
("insert a table" "insrer un tableau")
("insert a table or a matrix" "insrer un tableau ou une matrice")
("insert a textual operation" "insrer une opration textuelle")
("insert a wide symbol above" "insrer un accent large au dessus")
("insert a wide symbol below" "insrer un accent large en dessous")
("insert an" "insrer un")
("insert an accent" "insrer un accent")
("insert an arrow" "insrer une flche")
("insert an environment" "insrer un environnement")
("insert an n" "insrer une racine n")
("insert an operation on tuples" "insrer une opration sur des tuples")
("insert appendix" "insrer appendice")
("insert arccos" "insrer arccos")
("insert arcsin" "insrer arcsin")
("insert arctan" "insrer arctan")
("insert arg" "insrer arg")
("insert argument" "insrer argument")
("insert author" "insrer auteur")
("insert automatically generated content" "insrer du contenu automatiquement engendr")
("insert big contour integral" "insrer une grande intgrale de contour ")
("insert big coproduct" "insrer un grand coproduit")
("insert big direct sum" "insrer une grande somme directe")
("insert big dotted point" "insrer un grand point dans un cercle")
("insert big integral" "insrer une grande intgrale")
("insert big intersection" "insrer une grande intersection")
("insert big logical and" "insrer un grand et logique")
("insert big logical or" "insrer un grand ou logique")
("insert big product" "insrer un grand produit")
("insert big square union" "insrer une grande runion angulaire")
("insert big summation" "insrer une grande somme")
("insert big tensor product" "insrer un grand produit tensoriel")
("insert big union" "insrer une grande runion")
("insert big union sum" "insrer une grande union somme")
("insert big vertical space" "insrer une grande espace verticale")
("insert chapter" "insrer chapitre")
("insert column" "insrer colonne")
("insert column to the left" "insrer colonne vers la gauche")
("insert column to the right" "insrer colonne vers la droite")
("insert cos" "insrer cos")
("insert cosh" "insrer cosh")
("insert cot" "insrer cot")
("insert coth" "insrer coth")
("insert csc" "insrer csc")
("insert deg" "insrer deg")
("insert det" "insrer det")
("insert dim" "insrer dim")
("insert dollar" "insrer dollar")
("insert equation" "insrer quation")
("insert executable markup" "insrer du contenu excutable")
("insert exp" "insrer exp")
("insert fields" "insrer des champs")
("insert footnote" "insrer note en bas de page")
("insert formula" "insrer une formule")
("insert gcd" "insrer gcd")
("insert hom" "insrer hom")
("insert horizontal interword space" "insrer une espace")
("insert image" "insrer image")
("insert inactive markup" "insrer du contenu inactif")
("insert inf" "insrer inf")
("insert input field above" "insrer champ d'entre au dessus")
("insert input field below" "insrer champ d'entre en dessous")
("insert ker" "insrer ker")
("insert large" "insrer un grand")
("insert lg" "insrer lg")
("insert lim" "insrer lim")
("insert liminf" "insrer liminf")
("insert limsup" "insrer limsup")
("insert ln" "insrer ln")
("insert log" "insrer log")
("insert macro" "insrer macro")
("insert mathematics" "insrer des mathmatiques")
("insert max" "insrer max")
("insert medium horizontal space" "insrer une espace horizontale moyenne")
("insert medium vertical space" "insrer une espace verticale moyenne")
("insert min" "insrer min")
("insert negative horizontal space" "insrer une petite espace ngative")
("insert new item or number" "insrer un nouvel lment ou numro")
("insert new rows or columns" "insrer nouvelles lignes ou colonnes")
("insert or delete rows or columns" "insrer ou supprimer lignes ou colonnes")
("insert row" "insrer ligne")
("insert row above" "insrer ligne au dessus")
("insert row below" "insrer ligne en dessous")
("insert sec" "insrer sec")
("insert section" "insrer section")
("insert sharp" "insrer dise")
("insert sin" "insrer sin")
("insert sinh" "insrer sinh")
("insert small horizontal space" "insrer un petit espace horizontal")
("insert small vertical space" "insrer une petit espace verticale")
("insert structural markup" "insrer du contenu structurel")
("insert subsection" "insrer sous-section")
("insert subsubsection" "insrer sous-sous-section")
("insert sup" "insrer sup")
("insert tan" "insrer tan")
("insert tanh" "insrer tanh")
("insert text field" "insrer champ de texte")
("insert thick horizontal space" "insrer une espace horizontale paisse")
("insert title" "insrer titre")
("insert value" "insrer valeur")
("interactive command" "commande interactive")
("interfacing" "interfaage")
("interfacing TeXmacs with other systems" "interfaage de TeXmacs avec d'autres systmes")
("interjection" "interjection")
("interline separation" "sparation entre les lignes")
("interline space" "espace d'interligne")
("internationalization" "internationalisation")
("interparagraph space" "espace d'interparagraphe")
("interrupt execution" "interrompre l'xcution")
("introduction" "introduction")
("invisible" "invisible")
("invisible citation" "citation invisible")
("irish" "irlandais")
("is running" "est en marche")
("is tuple" "est tuplet")
("ispell does not respond" "ispell ne rpond pas")
("ispell is already busy" "ispell a dj t lanc")
("italian" "italien")
("italic" "italique")
("italic right" "italique droit")
("itemize" "liste")
("january" "janvier")
("japanese" "japonais")
("july" "juillet")
("june" "juin")
("justified" "justifi")
("justify text" "justifier le texte")
("key" "touche")
("keyboard" "clavier")
("keyboard equivalent" "raccourci clavier")
("keyboard modifiers" "modificateurs de clavier")
("keyboard shorthand" "raccourci clavier")
("keymaps" "claviers")
("keyword" "mot-clef")
("keywords" "mots-clefs")
("kill" "tuer")
("known bugs" "bogues connues")
("label" "tiquette")
("landscape" "paysage")
("language" "langue")
("large" "grand")
("large closing bracket" "grande parenthse fermante")
("large delimiter" "grand dlimiteur")
("large opening bracket" "grande parenthse ouvrante")
("large separator" "grand sparateur")
("last indentation" "dernire indentation")
("last page" "dernire page")
("latex command" "commande latex")
("latin" "latin")
("layout" "mise en page")
("left" " gauche")
("left arrow" "flche vers la gauche")
("left border" "limite  gauche")
("left cell border" "bordure de la cellule  gauche")
("left margin" "marge  gauche")
("left padding" "espacement  gauche")
("left prime" "prime  gauche")
("left ragged" "centr  gauche")
("left slanted" "italique vers la gauche")
("left subscript" "indice  gauche")
("left superscript" "exposant  gauche")
("left surrounding" "entourage  gauche")
("left table border" "bordure du tableau  gauche")
("legal" "lgal")
("lemma" "lemme")
("length" "longueur")
("less" "infrieur ")
("less or equal" "infrieur ou gal ")
("letter" "lettre")
("license" "licence")
("light" "lger")
("light grey" "gris clair")
("limitations" "limitations")
("limits" "limites")
("line" "droite")
("line break" "saut de ligne")
("line stretch" "tirabilit de lignes")
("link" "lien")
("link image" "lier image")
("list" "liste")
("list of figures" "liste de figures")
("list of tables" "liste de tableaux")
("load" "charger")
("load LaTeX file" "charger fichier LaTeX")
("load TeX file" "charger fichier TeX")
("load TeXmacs file" "charger fichier TeXmacs")
("load TeXmacs style file" "charger fichier de style TeXmacs")
("load a file" "charger un fichier")
("load buffer" "charger tampon")
("load file" "charger fichier")
("load html file" "charger fichier html")
("load image" "charger image")
("load in new window" "charger dans nouvelle fentre")
("load latex file" "charger fichier latex")
("load more recent autosave file" "charger le fichier plus rcent de sauvegarde automatique")
("load tex file" "charger fichier tex")
("load verbatim file" "charger fichier verbatim")
("loaded" "charg")
("long" "long")
("look and feel" "aspect de l'interface")
("look up" "rechercher")
("lower border" "limite en bas")
("m modifier" "modificateur M")
("macro" "macro")
("magenta" "mauve")
("magic" "magique")
("magnification" "agrandissement")
("magnified" "agrandi")
("main" "principal")
("main icon bar" "icnes principales")
("major changes" "changements majeurs")
("make a page insertion" "crer une insertion de page")
("make a subscript" "insrer un indice")
("make a superscript" "insrer un exposant")
("make acute" "crer un accent aigu")
("make bar" "crer une barre")
("make check" "crer un tchche")
("make fraction" "crer une fraction")
("make grave" "crer un accent grave")
("make hat" "crer un accent circonflexe")
("make label" "crer une tiquette")
("make negation" "crer une ngation")
("make page reference" "crer une rfrence de page")
("make reference" "crer une rfrence")
("make square root" "crer une racine carre")
("make tilde" "crer un tilde")
("make title" "construire titre")
("make vector" "crer un vecteur")
("making donations" "effectuer des dons")
("manual" "manuel")
("map to" "envoyer vers")
("march" "mars")
("margins" "marges")
("margins as on paper" "marges comme sur le papier")
("master" "matre")
("master file" "fichier matre")
("math" "maths")
("math font" "police mathmatique")
("math font family" "famille de police mathmatique")
("math font series" "espce de police mathmatique")
("math font shape" "forme de police mathmatique")
("mathematical" "mathmatique")
("mathematical and customized input" "entres mathmatiques et personnalises")
("mathematical font" "police mathmatique")
("mathematical formulas" "formules mathmatiques")
("mathematical input" "entres sous forme mathmatique")
("mathematical typesetting" "mise en page mathmatique")
("mathematics" "mathmatiques")
("matrix" "matrice")
("maximal" "maximal")
("maximal number of columns" "nombre minimal de colonnes")
("maximal number of rows" "nombre maximal de lignes")
("maximum mode" "mode maximum")
("may" "mai")
("medium" "moyen")
("medium skip" "saut moyen")
("meminfo" "info mmoire")
("merge" "fusion")
("messy" "embrouill")
("meta key" "touche meta")
("middle" "au milieu")
("minimal" "minimal")
("minimal number of columns" "nombre minimal de colonnes")
("minimal number of rows" "nombre minimal de lignes")
("minimum mode" "mode minimum")
("minus" "moins")
("miscellaneous" "divers")
("miscellaneous features" "fonctionnalits diverses")
("mod" "mod")
("mode" "mode")
("modifier" "modificateur")
("modify cell alignment" "modifier alignement de la cellule")
("modify cell border" "bordure de la cellule")
("modify cell padding" "espacement autour de la cellule")
("modify cell size" "modifier taille de la cellule")
("modify table border" "bordure du tableau")
("modify table padding" "espacement autour du tableau")
("mongolian" "mongol")
("more information about GNU TeXmacs can be found in the help" "pour plus de renseignements sur GNU TeXmacs, veuillez consulter le menu aide")
("mosaic" "mosaque")
("move down" "aller vers le bas")
("move object" "dplacer objet")
("move to the right when finished" "aller  droite pour terminer")
("move up" "aller en haut")
("multiline input" "entres multi-lignes")
("mutator tags" "balises mutantes")
("my documents" "mes documents")
("n-th" "n-ime")
("n-th root" "racine n-ime")
("name" "nom")
("negation" "ngation")
("new" "nouveau")
("new buffer" "nouveau tampon")
("new column" "nouvelle colonne")
("new double page" "nouvelle page double")
("new double page before" "nouvelle page double avant")
("new item" "nouvel lment")
("new line" "nouvelle ligne")
("new number" "nouveau nombre")
("new page" "nouvelle page")
("new page before" "nouvelle page avant")
("new paragraph" "nouveau paragraphe")
("new roman" "nouveau romain")
("new row" "nouvelle ligne")
("new table" "nouveau tableau")
("next" "suivant")
("next line" "ligne suivante")
("no changes need to be saved" "il n'y a pas de changements  sauvegarder")
("no dictionary for" "pas de dictionnaire pour")
("no first indentation" "pas de premire indentation")
("no indentation" "pas d'indentation")
("no line break" "pas de saut de ligne")
("no matches found" "je n'ai pas trouv d'occurrences")
("no matches found for" "pas d'occurrences pour")
("no more matches for" "pas d'autres occurrences de")
("no more redo information available" "tout a dj t refait")
("no more undo information available" "les renseignements pour dfaire ont t puiss")
("no name" "sans nom")
("no page break after" "pas de saut de page aprs")
("no page break before" "pas de saut de page avant")
("no spelling errors found in text" "le texte ne contient pas de fautes d'orthographe")
("no style" "sans style")
("none" "nant")
("normal" "normal")
("norwegian" "norvgien")
("not" "non")
("not equal" "diffrent de")
("not found" "non trouv")
("notation" "notation")
("note" "note")
("november" "novembre")
("number" "nombre")
("number equation" "numroter l'quation")
("number of columns" "nombre de colonnes")
("numbered equation" "quation numrote")
("numbered equations" "quations numrotes")
("numerator" "numrateur")
("numeric" "numrique")
("objectives" "objectifs")
("occurrences" "occurrences")
("october" "octobre")
("odd page footer" "en bas pour pages impaires")
("odd page header" "en-tte pour pages impaires")
("odd page margin" "marge pour pages impaires")
("odd page left margin" "marge  gauche pour pages impaires")
("odd page right margin" "marge  droite pour pages impaires")
("odd page shift" "dcalage pour les pages impaires")
("odd page text" "texte pour les pages impaires")
("off" "dsactiver")
("ok" "ok")
("old english" "vieil anglais")
("old slavonic" "vieux slave")
("old style" "ancien style")
("on" "activer")
("on cells" "par cellules")
("on columns" "par colonnes")
("on entire table" "par tableau entier")
("on rows" "par lignes")
("one spelling error has been corrected" "une faute d'orthographe a t corrige")
("online documentation" "documentation en ligne")
("online help" "aide en ligne")
("only inline tags" "balises en ligne seulement")
("open" "ouvrir")
("open a new buffer" "ouvrir un nouveau tampon")
("open new window" "ouvrir nouvelle fentre")
("opening" "ouverture")
("operation on named selection" "opration sur slection  spcifier")
("operation on primary selection" "opration sur slection primaire")
("operation on secondary selection" "opration sur slection secondaire")
("operation on ternary selection" "opration sur slection ternaire")
("optical" "optique")
("option" "option")
("options" "options")
("or" "ou")
("orange" "orange")
("orientation" "orientation")
("origin" "origine")
("original welcome message" "message original de bienvenue")
("other" "autre")
("other pages" "autres pages")
("other projects" "autres projets")
("other style" "autre style")
("outlined roman" "romain ddoubl")
("over" "sur")
("overbrace" "accolade au dessus")
("overline" "surlign")
("padding" "espacement")
("page" "page")
("page bottom margin" "marge de page en bas")
("page break" "saut de page")
("page break before" "saut de page avant")
("page height" "hauteur de page")
("page insertion" "insertion de page")
("page layout" "mise en page")
("page number text" "texte pour les numros de page")
("page numbering" "numrotation des pages")
("page reference" "rfrence de page")
("page right margin" "marge de page  droite")
("page setup" "paramtres d'impression")
("page top margin" "marge de page en haut")
("page type" "type de page")
("page width" "largeur de page")
("paper" "papier")
("paper type" "type de papier")
("papyrus" "papyrus")
("paragraph" "paragraphe")
("paragraph mode" "type de paragraphe")
("paragraph width" "largeur du paragraphe")
("part" "partie")
("past changes" "changements effectus")
("paste" "coller")
("paste from" "coller de")
("paste text" "coller du texte")
("path" "chemin")
("perform operations on cells" "oprer cellule par cellule")
("perform operations on columns" "oprer sur des colonnes")
("perform operations on entire table" "oprer sur le tableau entier")
("perform operations on rows" "oprer sur des lignes")
("permanent" "permanent")
("person" "personne")
("personal dictionary has been modified" "votre dictionnaire personnel a t modifi")
("phantasy" "fantaisie")
("philosophy" "philosophie")
("phoenician" "phnicien")
("phonetic" "phontique")
("pink" "rose")
("plain block" "bloc standard")
("plain tabular" "tableau standard")
("planned changes" "changements prvus")
("plans for the future" "projets pour l'avenir")
("please" "de grce")
("please wait" "patientez un instant s.v.p.")
("plugin" "greffon")
("plugins" "greffons")
("plus" "plus")
("polish" "polonais")
("porting TeXmacs to other platforms" "porter TeXmacs vers d'autres plate-formes")
("portrait" "portrait")
("portuguese" "portugais")
("position" "position")
("position float" "positionner flottant")
("position floating object" "positionner l'objet flottant")
("position the table" "positionner le tableau")
("postscript" "postscript")
("postscript image" "image postscript")
("pre-alpha release" "version pr-alpha")
("preamble" "prambule")
("preamble mode" "mode de prambule")
("preferences" "prfrences")
("presentation" "prsentation")
("presentation mode" "mode de prsentation")
("presentation tag" "balise de prsentation")
("preview before printing" "aperu avant l'impression")
("preview command" "commande de prvisualisation")
("preview with ghostview" "prvisualiser avec ghostview")
("previous" "prcdant")
("primary" "primaire")
("prime" "prime")
("print" "imprimer")
("print all" "imprimer le tout")
("print all to file" "imprimer le tout vers un fichier")
("print page selection" "imprimer slection de pages")
("print page selection to file" "imprimer slection de pages vers un fichier")
("print to postscript file" "imprimer vers fichier postscript")
("printer" "imprimante")
("printer dpi" "rsolution de l'imprimante en points par pouce")
("printing command" "commande pour imprimer")
("problem" "problme")
("professional" "professionnel")
("prog" "prog")
("prog font" "police pour programmer")
("prog font family" "famille de police de programmation")
("prog font series" "espce de police de programmation")
("prog font shape" "forme de police de programmation")
("program" "programme")
("program font" "police de programmation")
("program mode" "mode de programmation")
("programming" "programmation")
("progressive" "progressif")
("project" "projet")
("projects" "projets")
("prologue" "prologue")
("prompt on scripts" "demander l'acceptation de chaque script")
("prompts and default input" "prompts et entres par dfaut")
("proof" "dmonstration")
("proportional" "proportionnel")
("proportional typewriter" "proportionnel machine  crire")
("proposition" "proposition")
("query replace" "remplacement contrl")
("quit" "quitter")
("quotation" "citation")
("quote" "citer")
("range" "partie")
("really close it" "vraiment fermer")
("really huge" "vraiment norme")
("really quit" "voulez-vous vraiment quitter")
("recover autosave file" "recuprer fichier de sauvegarde automatique")
("red" "rouge")
("redo" "rpter")
("redo undone changes" "refaire des changements annuls")
("reduce bottom margin by" "rduire marge en bas de")
("reduce left margin by" "rduire marge  gauche de")
("reduce margins" "rduire les marges")
("reduce right margin by" "rduire marge  droite de")
("reduce top margin by" "rduire marge en haut de")
("reduction bottom margin" "rduction marge en bas")
("reduction even page margin" "rduction marge de page impaire")
("reduction odd page margin" "rduction marge de page paire")
("reduction page bottom margin" "rduction de la marge de page en bas")
("reduction page right margin" "rduction de la marge de page  droite")
("reduction page top margin" "rduction de la marge de page en haut")
("reduction right margin" "rduction marge  droite")
("reduction top margin" "rduction marge en haut")
("reference" "rfrence")
("reference guide" "guide de rfrence")
("reference guide for the TeXmacs primitives" "guide de rfrence pour les primitives TeXmacs")
("reference guide for the standard TeXmacs styles" "guide de rfrence pour les
styles standards de TeXmacs")
("references" "rfrences")
("regular" "normal")
("release" "version")
("reload" "recharger")
("remark" "remarque")
("remove all output fields" "enlever tous les champs de sortie")
("remove fields" "enlever des champs")
("remove input field" "enlever champ d'entre")
("remove input field above" "enlever champ d'entre au dessus")
("remove number" "enlever le numro")
("remove this switch" "enlever ce commutateur")
("renumber this page" "renumroter cette page")
("repeat" "rpter")
("repeat object" "rpter objet")
("replace" "remplacer")
("replace by" "remplacer par")
("replaced" "j'ai remplac")
("replaced one occurrence" "j'ai remplac une occurrence")
("reset" "remettre")
("resize object" "redimensionner objet")
("resized" "redimensionn")
("results of the search for" "resultats de la recherche pour")
("return" "entre")
("revert" "ractualiser")
("revert buffer" "actualiser tampon")
("right" " droite")
("right arrow" "flche vers la droite")
("right border" "limite  droite")
("right cell border" "bordure de la cellule  droite")
("right margin" "marge  droite")
("right padding" "espacement  droite")
("right page margin" "marge de page  droite")
("right ragged" "centr  droite")
("right subscript" "indice  droite")
("right superscript" "exposant  droite")
("right surrounding" "entourage  droite")
("right table border" "bordure du tableau  droite")
("rigid" "fixe")
("rigid horizontal" "horizontal fixe")
("rigid space" "espace fixe")
("roman" "romain")
("romanian" "roumain")
("root" "racine")
("rotate backward" "tourner en arrire")
("rotate forward" "tourner en avant")
("row" "ligne")
("row contains glued items" "la ligne contient des parties colles")
("runic" "runes")
("running author" "auteur courant")
("running title" "titre courant")
("russian" "russe")
("russian and Ukrainian users" "utilisateurs Russes et Ukrainiens")
("sample" "chantillon")
("sans serif" "sans srifs")
("save" "sauvegarder")
("save TeXmacs file" "sauvegarder fichier TeXmacs")
("save TeXmacs style file" "sauvegarder fichier de style TeXmacs")
("save as" "sauvegarder sous")
("save as LaTeX" "sauvegarder comme LaTeX")
("save as TeX" "sauvegarder comme TeX")
("save buffer" "sauvegarder tampon")
("save buffer as" "sauvegarder tampon sous")
("save file" "sauvegarder fichier")
("save html file" "sauvegarder fichier html")
("save image" "sauvegarder image")
("save latex file" "sauvegarder fichier latex")
("save tex file" "sauvegarder fichier tex")
("save this buffer" "sauvegarder ce tampon")
("save verbatim file" "sauvegarder fichier verbatim")
("saved" "sauvegard")
("scheme command" "commande Scheme")
("screen layout" "apparence sur cran")
("screen margins" "marges sur l'cran")
("script" "indice")
("script above" "indice en haut")
("script below" "indice en bas")
("script script size" "taille d'indices d'indices")
("script size" "taille d'indices")
("scripts not accepted" "des scripts ne sont jamais accepts")
("search" "chercher")
("search words in my documents" "chercher des mots dans mes documents")
("search words in the documentation" "chercher des mots dans la documentation")
("search words in the source code" "chercher des mots dans le code source")
("searching" "cherche")
("secondary" "secondaire")
("section" "section")
("security" "scurit")
("see" "voir")
("select a document style" "slectionner un style de document")
("select a foreground color" "slectionner une couleur")
("select a language" "slectionner une langue")
("selected region" "rgion slectionne")
("selection" "slection")
("selections" "slections")
("seminar" "sminaire")
("sending commands to TeXmacs" "envoyer des commandes  TeXmacs")
("separation between lines" "espacement entre les lignes")
("separation between paragraphs" "espacement entre les paragraphes")
("separator" "sparateur")
("september" "septembre")
("serb" "serbe")
("series" "espce")
("series|right" "droit")
("session" "session")
("session name" "nom de la session")
("session type" "type de la session")
("sessions" "sessions")
("set" "mettre")
("set background color of cell" "changer la couleur de la cellule")
("set cell mode" "mode d'opration sur les cellules")
("set extension center" "centre d'extension")
("set height" "changer hauteur")
("set height of cell" "changer la hauteur de la cellule")
("set margins" "changer indentations")
("set n" "entrer n")
("set or get environment variables" "changer ou obtenir des variables d'environnement")
("set paragraph margins" "changer les marges du paragraphe")
("set paragraph mode" "changer le mode d'alignement du paragraphe")
("set printer dpi" "spcifier rsolution de l'imprimante")
("set printing command" "commande pour imprimer")
("set span" "changer porte")
("set special cell properties" "changer proprits spciales de la cellule")
("set special table properties" "changer proprits spciales du tableau")
("set text width" "changer largeur du texte")
("set width" "changer largeur")
("set width of cell" "changer la largeur de la cellule")
("settings" "rglage")
("setup printer" "configurer imprimante")
("shape" "forme")
("shift-down" "shift-bas")
("shift-right" "shift-droite")
("short" "court")
("show" "afficher")
("show header and footer" "afficher en-tte et bas de page")
("show hidden" "montrer partie cache")
("show on screen" "montrer sur l'cran")
("shrinking factor" "facteur de rduction")
("signature" "signature")
("size" "taille")
("size limits" "limitations de taille")
("slanted" "oblique")
("sloppy" "relch")
("slovene" "slovne")
("small" "petit")
("small caps" "petites majuscules")
("small figure" "petite figure")
("small skip" "petit saut")
("small table" "petit tableau")
("source code" "code source")
("source tags" "balises du code source")
("space" "espace")
("space between lines" "espace d'interligne")
("space between paragraphs" "espace d'interparagraphe")
("spacing" "espacement")
("spanish" "espagnol")
("special" "spcial")
("special cell properties" "proprits spciales de la cellule")
("special table properties" "proprits spciales du tableau")
("specific" "spcifique")
("spell" "orthographe")
("spell checking complete" "le correcteur d'orthographe a termin")
("spelling error" "faute d'orthographe")
("spelling errors have been corrected" "fautes d'orthographe ont t corriges")
("split" "division")
("split session" "diviser session")
("square root" "racine carre")
("standard environment variables" "variables d'environnement standards")
("standard formats" "formats standards")
("standard TeXmacs styles" "styles TeXmacs standards")
("start" "dbut")
("start a new chapter" "commencer un nouveau chapitre")
("start a new section" "commencer une nouvelle section")
("start an interactive session" "commencer une session interactive")
("status bar" "barre d'tat")
("stretch" "tirer")
("stretchable" "tirable")
("stretchable horizontal" "horizontal tirable")
("stretchable vertical" "vertical tirable")
("stretched" "tir")
("stroke" "tiret")
("strokes" "tirets")
("strong" "important")
("structural" "structurel")
("style" "style")
("styles" "styles")
("stylesheet language" "language des feuilles de style")
("sub" "sous")
("subparagraph" "sous-paragraphe")
("subscript" "indice")
("subsection" "sous-section")
("subsub" "sous-sous")
("subsubsection" "sous-sous-section")
("subtitle" "sous-titre")
("summary" "rsum")
("summary of the principal TeXmacs tags" "les principaux marqueurs de contenu")
("superpose" "superposer")
("superposed" "superpos")
("superscript" "exposant")
("swedish" "sudois")
("swiss" "suisse")
("switch" "commutateur")
("switch to first" "passer au premier")
("switch to formula style" "basculer vers le style de formules")
("switch to last" "passer au dernier")
("switch to next" "passer au suivant")
("switch to previous" "passer au prcdant")
("switching and folding" "commuter et plier")
("symbol" "symbole")
("system command" "commande systme")
("system environment variables" "variables d'environnement systmes")
("tab" "tabulation")
("table" "tableau")
("table command" "commande de tableau")
("table of contents" "table des matires")
("tables" "tableaux")
("tabular" "tabuler")
("tabular material" "tableaux")
("teXmacs as an interface" "teXmacs en tant qu'interface")
("teXmacs fonts" "les polices TeXmacs")
("teXmacs notice" "avis sur TeXmacs")
("teXmacs style files" "fichiers de style TeXmacs")
("ternary" "tertiaire")
("test" "test")
("tex" "tex")
("text" "texte")
("text font" "police en mode texte")
("text height correction" "correction de l'hauteur du texte")
("text width" "largeur du texte")
("texts" "textes")
("th century bc" "ime sicle avant J.C.")
("th root" "ime racine")
("thai" "tha")
("the TeXmacs authors" "les auteurs de TeXmacs")
("the TeXmacs format" "le format TeXmacs")
("the application did not send its usual startup banner" "l'application n'a pas envoy son message habituel de lancement")
("the application does not reply" "l'application ne rpond pas")
("the application is already running" "l'application tourne dj")
("the boxes produced by the typesetter" "les botes produites par le metteur en page")
("the buffer has not been saved" "ce document n'a pas t sauvegard")
("the graphical user interface" "interface graphique d'utilisateur")
("the leaves of TeXmacs trees" "les feuilles des arbres TeXmacs")
("the mycas example" "l'exemple 'mycas'")
("the primitive TeXmacs constructs" "constructeurs TeXmacs primitifs")
("the standard TeXmacs styles" "les styles TeXmacs standards")
("theorem" "thorme")
("there are unsaved files" "tous les fichiers n'ont pas t sauvegards")
("this buffer has not been saved" "ce document n'a pas t sauvegard")
("this document has been produced using" "ce document a t conu avec")
("this line" "cette ligne")
("this page" "cette page")
("this page footer" "en bas de cette page")
("this page header" "en-tte pour cette page")
("tilda" "tilde")
("tilde" "tilde")
("times" "fois")
("tiny" "minuscule")
("title" "titre")
("to the left" "vers la gauche")
("to the right" "vers la droite")
("today" "aujourd'hui")
("tools" "outils")
("top" "en haut")
("top border" "bordure en haut")
("top cell border" "bordure en haut de la cellule")
("top cell padding" "espacement en haut de la cellule")
("top level" "niveau suprieur")
("top margin" "marge en haut")
("top padding" "espacement en haut")
("top table border" "bordure en haut du tableau")
("top table padding" "espacement en haut du tableau")
("translate" "traduire")
("tree" "arbre")
("tuple" "tuplet")
("turkish" "turque")
("tutorial" "tutoriel")
("type" "type")
("type a latex command followed by" "tapez une commande latex, puis")
("type body" "entrer corps")
("type denominator" "entrer dnominateur")
("type numerator" "entrer numrateur")
("type script" "entrer indice")
("typesetted boxes" "botes typographies")
("typewriter" "machine  crire")
("typewriter small caps" "petites majuscules machine  crire")
("typing a simple text" "saisie d'un texte simple")
("typing simple texts" "saisie de textes simples")
("ugaritic" "ougaritique")
("ukrainian" "ukrainien")
("underbrace" "accolade en dessous")
("underline" "soulign")
("undo" "annuler")
("undo last changes" "annuler les derniers changements")
("up" "en haut")
("update" "actualiser")
("update from web" "ractualiser  partir du rseau")
("update image links" "mise  jour des images lis")
("upper border" "limite en haut")
("upright" "droit")
("use TeXmacs" "utilisez TeXmacs")
("use a black color" "utiliser une couleur noire")
("use a blue color" "utiliser une couleur bleue")
("use a bold font" "utiliser une police grasse")
("use a brown color" "utiliser une couleur brune")
("use a calligraphic font" "utiliser une police calligraphique")
("use a green color" "utiliser une couleur verte")
("use a grey color" "utiliser une couleur grise")
("use a magenta color" "utiliser une couleur mauve")
("use a orange color" "utiliser une couleur orange")
("use a pink color" "utiliser une couleur rose")
("use a red color" "utiliser une couleur rouge")
("use a sans serif font" "utiliser une police sans srifs")
("use a typewriter font" "utiliser une police de machine  crire")
("use a white color" "utiliser une couleur blanche")
("use a yellow color" "utiliser une couleur jaune")
("use blackboard bold font" "utiliser la police pour tableau noir")
("use bold font series" "utiliser une police grasse")
("use calligraphic font" "utiliser la police calligraphique")
("use calligraphical font" "utiliser une police calligraphique")
("use footnote font size" "utiliser une trs petite police")
("use fraktur font" "utiliser la police Gothique")
("use huge font size" "utiliser une police norme")
("use italic font shape" "utiliser une police italique")
("use large font size" "utiliser une grande police")
("use left hand column as border" "utiliser colonne  gauche comme bordure")
("use medium font series" "utiliser une police d'paisseur normale")
("use normal font size" "utiliser une police de taille normale")
("use package" "utiliser paquetage")
("use paragraph width" "utiliser largeur du paragraphe")
("use really huge font size" "utiliser une police vraiment norme")
("use right font shape" "utiliser une police droite")
("use right hand column as border" "utiliser colonne  droite comme bordure")
("use roman font family" "utiliser la police romain")
("use row above as border" "utiliser ligne en haut comme bordure")
("use row below as border" "utiliser ligne en bas comme bordure")
("use sans serif font family" "utiliser la police sans srifs")
("use script font size" "utiliser une trs petite police")
("use slanted font shape" "utiliser une police oblique")
("use small capitals" "utiliser des petites majuscules")
("use small font size" "utiliser une petite police")
("use small-caps font shape" "utiliser une police de petites majuscules")
("use the blackboard bold font" "utiliser la police de tableau noir gras")
("use the fraktur font" "utiliser la police fraktur")
("use tiny font font size" "utiliser une police minuscule")
("use typewriter font family" "utiliser la police machine  crire")
("use very large font size" "utiliser une trs grande police")
("user manual" "manuel d'utilisation")
("user provided icons" "icnes dfinies par l'utilisateur")
("users of Cyrillic languages" "utilisateurs de langues Cyrilliques")
("value" "valeur")
("variable" "variable")
("variant" "variante")
("vector" "vecteur")
("verbatim" "verbatim")
("verse" "vers")
("vertical" "vertical")
("vertical after" "vertical aprs")
("vertical before" "vertical avant")
("vertical cell alignment" "alignement vertical de la cellule")
("vertical part" "partie verticale")
("vertical position" "position verticale")
("vertical space" "espace vertical")
("vertical table alignment" "alignmement vertical du tableau")
("vertically align cell to the base" "alignement verticale de la cellule  la base")
("vertically center the cell" "centrer la cellule verticalement")
("very large" "trs grand")
("very small" "trs petite")
("vietnamese" "vietnamien")
("view" "vue")
("visible" "visible")
("warning" "avertissement")
("web" "toile")
("welcome" "bienvenue")
("welcome to GNU TeXmacs" "bienvenue  GNU TeXmacs")
("what is new" "nouveauts")
("when finished" "pour terminer")
("while" "tant que")
("white" "blanc")
("wide accent" "accent large")
("wide bar" "barre large")
("width" "largeur")
("width is exactly the specified width" "utiliser la largeur spcifie")
("width is maximum of specified width and box width" "utiliser maximum de la largeur spcifie et la largeur de la bote")
("width is minimum of specified width and box width" "utiliser minimum de la largeur spcifie et la largeur de la bote")
("width magnification" "agrandissement de la largeur")
("window" "fentre")
("window height" "hauteur de fentre")
("window width" "largeur de fentre")
("windows key" "touche windows")
("with" "avec")
("write a macro" "crire un macro")
("write a name" "crire un nom")
("write bold mathematics" "crire des mathmatiques en gras")
("write bold text" "crire en gras")
("write italic text" "crire en italique")
("write sample text" "crire du texte illustratif")
("write strong text" "crire du texte important")
("write typewriter text" "crire du texte de machine  crire")
("write verbatim text" "crire en verbatim")
("writing data converters" "crire des convertisseurs de donnes")
("writing your own style files" "crire vos propres feuilles de style")
("written with TeXmacs" "conu avec TeXmacs")
("yellow" "jaune")
("you can also obtain" "vous pouvez galement obtenir")
("your document is back in its original state" "votre document est revenu dans son tat original")
("your first interface" "votre premire interface")
("your language" "votre langue")
